jQuery UI MultiSelect Widget by Eric Hynds

# erichynds

« Return to Blog Post

# jQuery UI MultiSelect Widget Demos

Download | Return to Blog Post & Documentation

- Basic
- Open/Close Animations
- Callbacks & Events
- Customize the Header
- Using selectedText/selectedList
- Max Checked
- Pre-selected/disabled Options
- Single Select
- Enable/Disable
- Using the Refresh Method
- Using the Position Utility
- Filter Plugin

Open Demo in New Window »